@@ -45,17 +45,17 @@ use warnings;
 package AtteanX::Store::LDF;
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 use Moo;
-use Attean::API::Store;
+use Attean;
 use Type::Tiny::Role;
 use Types::URI -all;
 use RDF::LDF;
 use namespace::clean;
 use Carp;
 
-with 'Attean::API::TripleStore', 'MooX::Log::Any';
+with 'Attean::API::TripleStore', 'Attean::API::CostPlanner', 'MooX::Log::Any';
 
 
 =head1 METHODS
@@ -207,6 +207,16 @@ sub cost_for_plan {
 	return;
 }
 
+=item plans_for_algebra($algebra)
+
+Returns an empty plan since access_plans generates the needed plans.
+
+=cut
+
+sub plans_for_algebra {
+	return ();
+}
+
 1;
 
 __END__
